@@ -50,7 +50,7 @@ CvsProgressDialog::CvsProgressDialog(const QString &text, QWidget *parent)
     hbox->addWidget(gear);
 
     resultbox = new QListBox(this);
-    resultbox->setEnabled(false);
+    resultbox->setSelectionMode(QListBox::NoSelection);
     QFontMetrics rb_fm(resultbox->fontMetrics());
     resultbox->setMinimumSize(rb_fm.width("0")*70,
 			      rb_fm.lineSpacing()*8);
