@@ -1,6 +1,6 @@
 /* 
- *  Copyright (C) 1999-2001 Bernd Gehrmann
- *                          bernd@physik.hu-berlin.de
+ *  Copyright (C) 1999-2002 Bernd Gehrmann
+ *                          bernd@mail.berlios.de
  *
  * This program may be distributed under the terms of the Q Public
  * License as defined by Trolltech AS of Norway and appearing in the
@@ -11,6 +11,8 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
 
+#include "diffdlg.h"
+
 #include <qpushbutton.h>
 #include <qcheckbox.h>
 #include <qcombobox.h>
@@ -20,17 +22,16 @@
 #include <qkeycode.h>
 #include <qfileinfo.h>
 #include <kbuttonbox.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <kconfig.h>
 #include <klocale.h>
 #include <ktempfile.h>
 #include <kprocess.h>
+
 #include "misc.h"
 #include "cervisiapart.h"
 #include "cvsprogressdlg.h"
 #include "diffview.h"
-#include "diffdlg.h"
-#include "diffdlg.moc"
 
 
 DiffDialog::Options *DiffDialog::options = 0;
@@ -75,7 +76,6 @@ DiffDialog::DiffDialog(QWidget *parent, const char *name, bool modal)
     syncbox->setChecked(true);
     connect( syncbox, SIGNAL(toggled(bool)),
 	     this, SLOT(toggleSynchronize(bool)) );
-    syncbox->setMinimumSize(syncbox->sizeHint());
 
     itemscombo = new QComboBox(this);
     itemscombo->insertItem("");
@@ -104,13 +104,13 @@ DiffDialog::DiffDialog(QWidget *parent, const char *name, bool modal)
     
     QFrame *frame = new QFrame(this);
     frame->setFrameStyle(QFrame::HLine | QFrame::Sunken);
-    frame->setMinimumHeight(frame->sizeHint().height());
     layout->addWidget(frame, 0);
 
     KButtonBox *buttonbox = new KButtonBox(this);
+    QPushButton *helpbutton = buttonbox->addButton(i18n("&Help"));
+    helpbutton->setAutoDefault(false);
     buttonbox->addStretch();
-    connect( buttonbox->addButton(i18n("&Close")), SIGNAL(clicked()),
-	     SLOT(reject()) );
+    QPushButton *closebutton = buttonbox->addButton(i18n("&Close"));
     buttonbox->layout();
     layout->addWidget(buttonbox, 0);
 
@@ -118,6 +118,9 @@ DiffDialog::DiffDialog(QWidget *parent, const char *name, bool modal)
     setMinimumSize(fm.width("0123456789")*12,
 		   fm.lineSpacing()*30);
 
+    connect( helpbutton, SIGNAL(clicked()), SLOT(helpClicked()) );
+    connect( closebutton, SIGNAL(clicked()), SLOT(reject()) );
+    
     if (options)
         {
             resize(options->size);
@@ -259,11 +262,11 @@ public:
 bool DiffDialog::parseCvsDiff(const QString &sandbox, const QString &repository,
                               const QString &filename, const QString &revA, const QString &revB)
 {
-    QStrList linesA, linesB;
+    QStringList linesA, linesB;
     int linenoA, linenoB;
     enum { Normal, VersionA, VersionB } state;
 
-    setCaption(i18n("CVS Diff: ") + filename);
+    setCaption(i18n("CVS Diff: %1").arg(filename));
     revlabel1->setText( revA.isEmpty()?
                         QString(i18n("Repository"))
                         : i18n("Revision ")+revA );
@@ -293,36 +296,36 @@ bool DiffDialog::parseCvsDiff(const QString &sandbox, const QString &repository,
                     QString revAFilename = tempFileName(QString("-")+revA);
                     QString revBFilename = tempFileName(QString("-")+revB);
                     cmdline += " -r ";
-                    cmdline += revA;
+                    cmdline += KShellProcess::quote(revA);
                     cmdline += " ";
                     cmdline += KShellProcess::quote(filename);
                     cmdline += " > ";
-                    cmdline += revAFilename;
+                    cmdline += KShellProcess::quote(revAFilename);
                     cmdline += " ; cvs update -p ";
                     cmdline += " -r ";
-                    cmdline += revB;
+                    cmdline += KShellProcess::quote(revB);
                     cmdline += " ";
                     cmdline += KShellProcess::quote(filename);
                     cmdline += " > ";
-                    cmdline += revBFilename;
+                    cmdline += KShellProcess::quote(revBFilename);
                     
-                    extcmdline += revAFilename;
+                    extcmdline += KShellProcess::quote(revAFilename);
                     extcmdline += " ";
-                    extcmdline += revBFilename;
+                    extcmdline += KShellProcess::quote(revBFilename);
                 } else {
                     // We're comparing to a file, and perhaps one revision
                     QString revAFilename = tempFileName(revA);
                     if (!revA.isEmpty())
                         {
                             cmdline += " -r ";
-                            cmdline += revA;
+                            cmdline += KShellProcess::quote(revA);
                         }
                     cmdline += " ";
                     cmdline += KShellProcess::quote(filename);
                     cmdline += " > ";
-                    cmdline += revAFilename;
+                    cmdline += KShellProcess::quote(revAFilename);
                     
-                    extcmdline += revAFilename;
+                    extcmdline += KShellProcess::quote(revAFilename);
                     extcmdline += " ";
                     extcmdline += KShellProcess::quote(QFileInfo(filename).absFilePath());
                 }
@@ -336,19 +339,19 @@ bool DiffDialog::parseCvsDiff(const QString &sandbox, const QString &repository,
             return false;
         }
 
-    QString cmdline = cvsClient(repository) + " -f diff ";
+    QString cmdline = cvsClient(repository) + " diff ";
     cmdline += config->readEntry("DiffOptions", "");
     cmdline += " -U ";
     cmdline += QString().setNum((int)config->readUnsignedNumEntry("ContextLines", 65535));
     if (!revA.isEmpty())
 	{
 	    cmdline += " -r ";
-	    cmdline += revA;
+	    cmdline += KShellProcess::quote(revA);
 	}
     if (!revB.isEmpty())
 	{
 	    cmdline += " -r ";
-	    cmdline += revB;
+	    cmdline += KShellProcess::quote(revB);
 	}
     cmdline += " ";
     cmdline += KShellProcess::quote(filename);
@@ -358,7 +361,7 @@ bool DiffDialog::parseCvsDiff(const QString &sandbox, const QString &repository,
     if (!l.execCommand(sandbox, repository, cmdline, "diff"))
         return false;
 
-    QCString line;
+    QString line;
     while ( l.getOneLine(&line) && line.left(3) != "+++")
         ;
     
@@ -375,7 +378,7 @@ bool DiffDialog::parseCvsDiff(const QString &sandbox, const QString &repository,
                 }
             if (line.length() < 1)
                 continue;
-            char marker = line[0];
+            QChar marker = line[0];
             line.remove(0, 1);
             
             if (marker == '-')
@@ -402,16 +405,16 @@ bool DiffDialog::parseCvsDiff(const QString &sandbox, const QString &repository,
                                                          linenoB+1, linesB.count());
                             itemscombo->insertItem(str);
                         }
-                    QStrListIterator itA(linesA);
-                    QStrListIterator itB(linesB);
-                    for (; itA.current() || itB.current(); ++itA, ++itB)
+                    QStringList::ConstIterator itA = linesA.begin();
+                    QStringList::ConstIterator itB = linesB.begin();
+                    while (itA != linesA.end() || itB != linesB.end())
                         {
-                            if (itA.current())
+                            if (itA != linesA.end())
                                 {
-                                    diff1->addLine(itA.current(), DiffView::Neutral,
+                                    diff1->addLine(*itA, DiffView::Neutral,
                                                    ++linenoA);
-                                    if (itB.current())
-                                        diff2->addLine(itB.current(), DiffView::Change,
+                                    if (itB != linesB.end())
+                                        diff2->addLine(*itB, DiffView::Change,
                                                        ++linenoB);
                                     else
                                         diff2->addLine("", DiffView::Delete);
@@ -419,9 +422,14 @@ bool DiffDialog::parseCvsDiff(const QString &sandbox, const QString &repository,
                             else
                                 {
                                     diff1->addLine("", DiffView::Neutral);
-                                    diff2->addLine(itB.current(), DiffView::Insert,
+                                    diff2->addLine(*itB, DiffView::Insert,
                                                    ++linenoB);
                                 }
+
+                            if (itA != linesA.end())
+                                ++itA;
+                            if (itB != linesB.end())
+                                ++itB;
                         }
                     state = Normal;
                     linesA.clear();
@@ -445,16 +453,16 @@ bool DiffDialog::parseCvsDiff(const QString &sandbox, const QString &repository,
                                          linenoB+1, linesB.count());
             itemscombo->insertItem(str);
         }
-    QStrListIterator itA(linesA);
-    QStrListIterator itB(linesB);
-    for (; itA.current() || itB.current(); ++itA, ++itB)
+    QStringList::ConstIterator itA = linesA.begin();
+    QStringList::ConstIterator itB = linesB.begin();
+    while (itA != linesA.end() || itB != linesB.end())
         {
-            if (itA.current())
+            if (itA != linesA.end())
                 {
-                    diff1->addLine(itA.current(), DiffView::Neutral,
+                    diff1->addLine(*itA, DiffView::Neutral,
                                    ++linenoA);
-                    if (itB.current())
-                        diff2->addLine(itB.current(), DiffView::Change,
+                    if (itB != linesB.end())
+                        diff2->addLine(*itB, DiffView::Change,
                                        ++linenoB);
                     else
                         diff2->addLine("", DiffView::Delete);
@@ -462,13 +470,17 @@ bool DiffDialog::parseCvsDiff(const QString &sandbox, const QString &repository,
             else
                 {
                     diff1->addLine("", DiffView::Neutral);
-                    diff2->addLine(itB.current(), DiffView::Insert,
+                    diff2->addLine(*itB, DiffView::Insert,
                                    ++linenoB);
                 }
+            
+            if (itA != linesA.end())
+                ++itA;
+            if (itB != linesB.end())
+                ++itB;
         }
 
     updateNofN();
-    itemscombo->setMinimumSize(itemscombo->sizeHint());
  
     return true;
 }
@@ -544,6 +556,15 @@ void DiffDialog::forwClicked()
     updateHighlight(newitem);
 }
 
+
+void DiffDialog::helpClicked()
+{
+    kapp->invokeHelp("diff", "cervisia");
+}
+
+#include "diffdlg.moc"
+
+
 // Local Variables:
 // c-basic-offset: 4
 // End:
