@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 1999-2001 Bernd Gehrmann
- *                          bernd@physik.hu-berlin.de
+ *  Copyright (C) 1999-2002 Bernd Gehrmann
+ *                          bernd@mail.berlios.de
  *
  * This program may be distributed under the terms of the Q Public
  * License as defined by Trolltech AS of Norway and appearing in the
@@ -11,23 +11,25 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
 
+#include "logtree.h"
 
-#include <qtooltip.h>
+#include <qapplication.h>
 #include <qpainter.h>
-#include <qapp.h>
+#include <qstylesheet.h>
+#include <qtooltip.h>
+#include <kdebug.h>
+#include <kglobalsettings.h>
+
 #include "tiplabel.h"
 #include "misc.h"
 
-#include "logtree.h"
-#include "logtree.moc"
 
-
-static const int BORDER = 8;
-static const int INSPACE = 3;
+const int LogTreeView::BORDER = 8;
+const int LogTreeView::INSPACE = 3;
 
 static bool static_initialized = false;
-static int  static_width;
-static int  static_height;
+static int static_width;
+static int static_height;
 
 
 class LogTreeItem
@@ -56,7 +58,7 @@ public:
 
 
 LogTreeView::LogTreeView(QWidget *parent, const char *name)
-    : QTableView(parent, name)
+    : QtTableView(parent, name)
 {
     if (!static_initialized)
 	{
@@ -91,7 +93,14 @@ LogTreeView::LogTreeView(QWidget *parent, const char *name)
 
 LogTreeView::~LogTreeView()
 {
-    qApp->installEventFilter(this);
+    delete currentLabel;
+}
+
+
+void LogTreeView::hideLabel()
+{
+    delete currentLabel;
+    currentLabel = 0;
 }
 
 
@@ -374,9 +383,8 @@ void LogTreeView::paintRevisionCell(QPainter *p,
                     p->setPen(colorGroup().base());
                 }
 #else
-	    // XXX: This is a hack
-	    p->fillRect(x, y, boxwidth, boxheight, QApplication::winStyleHighlightColor());
-	    p->setPen(white);
+	    p->fillRect(x, y, boxwidth, boxheight, KGlobalSettings::highlightColor());
+	    p->setPen(KGlobalSettings::highlightedTextColor());
 
 #endif
         }
@@ -428,30 +436,22 @@ void LogTreeView::mousePressEvent(QMouseEvent *e)
 	}
 }
 
-void LogTreeView::hideLabel()
-{
-    if (currentLabel)
-        currentLabel->hide();
-    delete currentLabel;
-    currentLabel = 0;
-}
 
-void LogTreeView::windowActivationChange( bool )
-{
-    hideLabel();
-}
-
-bool LogTreeView::eventFilter(QObject *o, QEvent *e)
+void LogTreeView::mouseMoveEvent(QMouseEvent *e)
 {
+#if 0
     if (o != this || e->type() != QEvent::MouseMove || !isActiveWindow())
-        return QTableView::eventFilter(o, e);
+        return QtTableView::eventFilter(o, e);
+#endif
+    if (!isActiveWindow())
+        return;
 
     int row = findRow(static_cast<QMouseEvent*>(e)->y());
     int col = findCol(static_cast<QMouseEvent*>(e)->x());
-    if (row != currentRow || col != currentCol)
-        {
-            hideLabel();
-        }
+    if (row != currentRow || col != currentCol) {
+        //        kdDebug() << "hidden because of row/col change" << endl;
+        hideLabel();
+    }
 
     LogTreeItem *item = 0;
 
@@ -465,22 +465,21 @@ bool LogTreeView::eventFilter(QObject *o, QEvent *e)
 
     if (!currentLabel && item)
         {
-            if (true)
-            //            if (!item->author.isNull())
+            if (!item->author.isNull())
                 {
                     QString text = "<qt><b>";
-                    text += item->rev;
+                    text += QStyleSheet::escape(item->rev);
                     text += "</b>&nbsp;&nbsp;";
-                    text += item->author;
+                    text += QStyleSheet::escape(item->author);
                     text += "&nbsp;&nbsp;<b>";
-                    text += item->date;
+                    text += QStyleSheet::escape(item->date);
                     text += "</b>";
                     QStringList list2 = QStringList::split("\n", item->comment);
                     QStringList::Iterator it2;
                     for (it2 = list2.begin(); it2 != list2.end(); ++it2)
                         {
                             text += "<br>";
-                            text += (*it2);
+                            text += QStyleSheet::escape(*it2);
                         }
                     if (!item->tagcomment.isEmpty())
                         {
@@ -490,7 +489,7 @@ bool LogTreeView::eventFilter(QObject *o, QEvent *e)
                             for (it3 = list3.begin(); it3 != list3.end(); ++it3)
                                 {
                                     text += "<br>";
-                                    text += (*it3);
+                                    text += QStyleSheet::escape(*it3);
                                 }
                             text += "</i>";
                         }
@@ -503,8 +502,24 @@ bool LogTreeView::eventFilter(QObject *o, QEvent *e)
                     currentCol = col;
                 }
         }
+}
 
-    return QTableView::eventFilter(o, e);
+
+void LogTreeView::windowActivationChange(bool oldActive)
+{
+    //    kdDebug() << "windowActivationChange" << endl;
+    hideLabel();
+    QtTableView::windowActivationChange(oldActive);
+}
+
+
+void LogTreeView::leaveEvent(QEvent *e)
+{
+    //    kdDebug() << "leaveEvent" << endl;
+    // has strange effects
+    // hideLabel();
+    hideLabel();
+    QtTableView::leaveEvent(e);
 }
 
 
@@ -565,6 +580,8 @@ int LogTreeView::cellHeight(int row)
     return rowHeights[row];
 }
 
+#include "logtree.moc"
+
 
 // Local Variables:
 // c-basic-offset: 4
