@@ -1,6 +1,6 @@
 /* 
- *  Copyright (C) 1999-2001 Bernd Gehrmann
- *                          bernd@physik.hu-berlin.de
+ *  Copyright (C) 1999-2002 Bernd Gehrmann
+ *                          bernd@mail.berlios.de
  *
  * This program may be distributed under the terms of the Q Public
  * License as defined by Trolltech AS of Norway and appearing in the
@@ -12,9 +12,10 @@
  */
 
 
-#ifndef _SETTINGSDLG_H_
-#define _SETTINGSDLG_H_
+#ifndef SETTINGSDLG_H
+#define SETTINGSDLG_H
 
+#include <qpushbutton.h>
 #include <kdialogbase.h>
 
 class QCheckBox;
@@ -25,11 +26,13 @@ class KIntegerLine;
 class KIntNumInput;
 class KLineEdit;
 class KConfig;
-class KURLRequester;
+class KColorButton;
+
 
 class FontButton : public QPushButton
 {
     Q_OBJECT
+
 public:
     FontButton( const QString &text, QWidget *parent=0, const char *name=0 );
 
@@ -59,6 +62,7 @@ private:
     KLineEdit *cvspathedit;
     QComboBox *compressioncombo;
     KLineEdit *usernameedit;
+    KLineEdit *editoredit;
     KLineEdit *diffoptedit;
     KLineEdit *extdiffedit;
     QCheckBox *remotestatusbox;
@@ -72,6 +76,12 @@ private:
     FontButton *annotatefontbox;
     FontButton *difffontbox;
     QCheckBox *splitterbox;
+    KColorButton *conflictbutton;
+    KColorButton *localchangebutton;
+    KColorButton *remotechangebutton;
+    KColorButton *diffchangebutton;
+    KColorButton *diffinsertbutton;
+    KColorButton *diffdeletebutton;
 };
 
 #endif
