@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 1999-2001 Bernd Gehrmann
- *                          bernd@physik.hu-berlin.de
+ *  Copyright (C) 1999-2002 Bernd Gehrmann
+ *                          bernd@mail.berlios.de
  *
  * This program may be distributed under the terms of the Q Public
  * License as defined by Trolltech AS of Norway and appearing in the
@@ -12,13 +12,12 @@
  */
 
 
+#include "tiplabel.h"
+
 #include <qapplication.h>
 #include <qsimplerichtext.h>
 #include <qtooltip.h>
 
-#include "tiplabel.h"
-#include "tiplabel.moc"
-
 
 TipLabel::TipLabel(const QString &text)
     : QLabel(0, "annotate label", WStyle_Customize|WStyle_StaysOnTop|WStyle_NoBorder|WStyle_Tool|WX11BypassWM)
@@ -39,8 +38,10 @@ void TipLabel::showAt(QPoint pos)
 {
     adjustSize();
 
-    pos = QPoint(QMIN(pos.x(), QApplication::desktop()->width()-width()),
-                 QMIN(pos.y(), QApplication::desktop()->height()-height()));
+    QPoint maxpos = QPoint(QMAX(QApplication::desktop()->width()-width(), 0),
+                           QMAX(QApplication::desktop()->height()-height(), 0));
+    pos = QPoint(QMIN(pos.x(), maxpos.x()),
+                 QMIN(pos.y(), maxpos.y()));
     move(pos);
     show();
 }
@@ -56,3 +57,11 @@ QSize TipLabel::sizeHint() const
 {
     return QSize(whint, heightForWidth(whint));
 }
+
+#include "tiplabel.moc"
+
+
+// Local Variables:
+// c-basic-offset: 4
+// End:
+
