@@ -133,8 +133,6 @@ private slots:
     void addToRecentFiles(KURL url);
     
     void toggleEditMode();
-    void optionsShowToolbar(bool on);
-    void optionsShowNavBar(bool on);
     void optionsShowStatusbar(bool on);
     void optionsEditToolbars();
     void checkMenuItemTools();
