@@ -128,7 +128,7 @@ void KBabelPreferences::updateSaveSettings(SaveSettings settings)
     _saveSettings=settings;
 }
 
-void KBabelPreferences::updateCatManSettings(CatManSettings settings)
+void KBabelPreferences::updateCatManSettings(CatManSettings /*settings*/)
 {
 //    _catManPage->setSettings(settings);
 //    _catManSettings=settings;
