@@ -26,7 +26,6 @@
 #include <config.h>
 #endif
 
-//class MyMultiLineEdit;
 class MsgMultiLineEdit;
 class EditCommand;
 class QSplitter;
@@ -37,8 +36,10 @@ class QPopupMenu;
 class KLed;
 class FindDialog;
 class ReplaceDialog;
+class QListBoxItem;
 class QTextView;
 class QTabWidget;
+class KListBox;
 class KSpell;
 class KSpellConfig;
 class KBabelDictBox;
@@ -52,6 +53,7 @@ struct ModuleInfo;
 #include <catalogview.h>
 #include "kbcatalog.h"
 #include "settings.h"
+#include "context.h"
 
 /**
  * This is the main view class for KBabel.  Most of the non-menu,
@@ -69,7 +71,7 @@ public:
     * Default constructor
     * @param buildLeds flag, if status leds should be created in editor
     */
-    KBabelView(KBCatalog* catalog,QWidget *parent);
+    KBabelView(KBCatalog* catalog,QWidget *parent, QString configFile = QString::null);
 
     /**
     * Destructor
@@ -80,15 +82,16 @@ public:
      * @return the view, that has opened file url or 0 if this
      * file is not opened
      */
-    static KBabelView *viewForURL(const KURL& url);
+    static KBabelView *viewForURL(const KURL& url, const QString project);
 
     /** 
      * @return the view, that has no opened file url or 0 if there
      * is no such view
      */
-    static KBabelView *emptyView();
+    static KBabelView *emptyView(const QString project);
     
     KURL currentURL() const;
+    QString project() const { return _configFile; }
     bool isLastView() const;
     bool isModified() const;
     /** the edit mode of the entry-editors*/
@@ -98,20 +101,23 @@ public:
     void setOverwriteMode(bool ovr);
     bool isSearching() const;
 
-    void saveView();
-    void restoreView();
+    void saveView(KConfig *config);
+    void restoreView(KConfig *config);
     void saveSession(KConfig*);
     void restoreSession(KConfig*);
 
-    void readSettings();
-    void saveSettings();
+    void readSettings(KConfig* config);
+    void saveSettings(KConfig* config);
 
     SearchSettings searchSettings() const;
     EditorSettings editorSettings() const{return _settings;}
+    SourceContextSettings sourceContextSettings() const;
 
     void openTemplate(const KURL& openURL, const KURL& saveURL);
     bool saveFile(bool checkSyntax=true);
     bool saveFileAs(KURL url = KURL(), bool checkSyntax=true);
+    bool saveFileSpecial();
+    
     /**
     * Checks, if the file has been modified. If true, it askes the user if he wants
     * to save, discard or cancel. If the users chose save, it saves the file.
@@ -155,6 +161,7 @@ public:
    void setRMBEditMenu(QPopupMenu*);
    void setRMBSearchMenu(QPopupMenu*);
    void setTagsMenu(QPopupMenu*);
+   void setArgsMenu(QPopupMenu*);
 
    QPtrList<ModuleInfo> dictionaries();
 
@@ -165,12 +172,14 @@ public:
 public slots:
     /** opens a filedialog and asks for an url */
     void open();
-    void open(const KURL& url, bool checkModified=true);
+    void open(const KURL& url, const QString & package=QString::null, bool checkModified=true);
+    void setFilePackage();
     void revertToSaved();
 
     void setSettings(SearchSettings settings);
     void setSettings(EditorSettings settings);
     void setSettings(CatManSettings settings);
+    void setSettings(SourceContextSettings settings);
 
     void undo();
     void redo();
@@ -217,7 +226,10 @@ public slots:
     void diffShowOrig();
     bool openDiffFile();
     void insertNextTag();
+    void insertNextArg();
+    void insertTagFromTool( QListBoxItem *item );
     void showTagsMenu();
+    void showArgsMenu();
 
    
     /** hides or shows the editor for the comments */
@@ -262,6 +274,17 @@ public slots:
      */
     bool checkSingularPlural();
 
+    /**
+     * checks if the message is well-formed XML
+     * @see CatalogItem::checkXmlTags
+     */
+    bool checkXmlTags();
+
+    /** 
+     * perform all checks listed above
+     */
+    bool checkAll();
+
     void stopSearch();
     void startSearch();
     void startSelectionSearch();
@@ -361,8 +384,13 @@ signals:
 
     void signalNextTagAvailable(bool);
     void signalTagsAvailable(bool);
+    
+    void signalNextArgAvailable(bool);
+    void signalArgsAvailable(bool);
 
     void signalCursorPosChanged(int line, int col);
+    
+    void signalSpellcheckDone(int result);
 
 private:
    /**
@@ -481,6 +509,11 @@ private slots:
 
    void updateTags();
    
+   /** inserts the nth argument from the available arguments into msgstr*/
+   void insertArg(int n);
+
+   void updateArgs();
+   
    void showTryLaterMessageBox();
    
 private:
@@ -491,6 +524,8 @@ private:
    MsgMultiLineEdit* msgidLabel;
    QTextView *contextView;
    KBabelDictBox* dictBox;
+   SourceContext* sourceView;
+   KListBox* taglistView;
    GotoDialog* _gotoDialog;
    FindDialog* _findDialog;
    FindDialog* _replaceDialog;
@@ -556,10 +591,18 @@ private:
    QStringList _tags;
    QPopupMenu *_tagsMenu;
 
+   QStringList _args;
+   QPopupMenu *_argsMenu;
+
    bool _diffEnabled;
    bool _loadingDiffFile;
    bool _diffing;
    
+   /*
+    * flag, set if editing KDE documentation PO-file
+    */
+   bool _editingDocumentation;
+
 //spellcheck things
 private:
    struct Position
@@ -590,9 +633,6 @@ private:
       // needed if words with '-' are treated as seperate words
       int inWordCorrection;
 
-      bool haveFixedKSpell;
-      bool checkedKSpell;
-
       QStringList origWords;
       QStringList newWords;
   
@@ -623,7 +663,12 @@ private slots:
    void spellResult(bool);
    void spellCleanDone();
    void spellAddIgnore(const QString &);
+   // initialize spellchecking struct
+   void cleanUpSpellStruct();
    
+private:
+   // configuration file for projects
+   QString _configFile;   
 };
 
 #endif // KBABELVIEW_H
