@@ -3,6 +3,8 @@
 
   Copyright (C) 1999-2000 by Matthias Kiefer
                             <matthias.kiefer@gmx.de>
+		2001-2003 by Stanislav Visnovsky
+			    <visnovsky@kde.org>
 			    
   Alt+123 feature idea taken from KOffice by David Faure <david@mandrakesoft.com>.
 
@@ -83,7 +85,7 @@ void MyMultiLineEdit::processCommand(EditCommand* cmd, bool undo)
   else _invisibleHighlight.setInactive( newcg );
   setPalette( _invisibleHighlight );   
    
-  if(delcmd->offset <= _lastParagraphOffset)
+  if(delcmd->offset <= (int)_lastParagraphOffset)
   {
     _lastParagraph=0;
     _lastParagraphOffset=0;
@@ -211,7 +213,7 @@ void MyMultiLineEdit::doKeyboardAction( KeyboardAction action )
 	    int x,y;
 	    getCursorPosition( &x, &y );
 	    QString s = text(x);
-	    if( y < s.length()-1  ) // not the end of paragraph
+	    if( y < (int)s.length()-1  ) // not the end of paragraph
 	    {
 		QString delText = s.mid( y, s.length()-y-1);
 	        emit signalUndoCmd( new DelTextCmd(currentIndex(), delText ) );
@@ -220,6 +222,7 @@ void MyMultiLineEdit::doKeyboardAction( KeyboardAction action )
 		    emit signalUndoCmd( new DelTextCmd(currentIndex(), "\n" ) );
 	}
         break;
+      default: break;
   }
 
   QTextEdit::doKeyboardAction( action );
@@ -266,7 +269,7 @@ void MyMultiLineEdit::insert( const QString & text, bool indent, bool checkNewLi
 	int endRow,endCol;
 	getSelection(&row,&col,&endRow,&endCol);
 
-	if( row<_lastParagraph )
+	if( row<(int)_lastParagraph )
 	{
 	    _lastParagraph=0;
 	    _lastParagraphOffset=0;
@@ -400,7 +403,7 @@ void MyMultiLineEdit::my_del()
             QString delTxt(s[cursorX]);
             emit signalUndoCmd(new DelTextCmd(offset,delTxt));
          }
-         else if( cursorY < paragraphs()-1 || ( (cursorY == paragraphs()-1) && (cursorX < text( paragraphs()-1 ).length()-1 ) ) )// !atEnd() )
+         else if( cursorY < (int)paragraphs()-1 || ( (cursorY == (int)paragraphs()-1) && (cursorX < (int)text( paragraphs()-1 ).length()-1 ) ) )// !atEnd() )
          {
             emit signalUndoCmd(new DelTextCmd(offset,"\n"));
          }
@@ -422,7 +425,7 @@ void MyMultiLineEdit::removeSelectedText(int selNum)
 	  int paraFrom, idxFrom, paraTo, idxTo;
 	  QTextEdit::getSelection( &paraFrom, &idxFrom, &paraTo, &idxTo );
 	  
-	  if( paraFrom < _lastParagraph )
+	  if( paraFrom < (int)_lastParagraph )
 	  {
 	    _lastParagraph=0;
 	    _lastParagraphOffset=0;
@@ -485,15 +488,15 @@ void MyMultiLineEdit::offset2Pos(int offset, int &paragraph, int &index) const
     }
 }
 
-int MyMultiLineEdit::pos2Offset(int paragraph, int index)
+int MyMultiLineEdit::pos2Offset(uint paragraph, uint index)
 {
-    paragraph = QMAX( QMIN( paragraph, paragraphs() - 1), 0 ); // Sanity check
-	index  = QMAX( QMIN( index,  paragraphLength( paragraph )), 0 ); // Sanity check
+    paragraph = QMAX( QMIN( (int)paragraph, paragraphs() - 1), 0 ); // Sanity check
+	index  = QMAX( QMIN( (int)index,  paragraphLength( paragraph )), 0 ); // Sanity check
     {
-        int lastI;
+        uint lastI;
 	lastI  = paragraphLength( paragraph );
-	int i = 0; 
-	int tmp = 0;
+	uint i = 0; 
+	uint tmp = 0;
 
 	if( paragraph>=_lastParagraph )
 	{
@@ -554,6 +557,24 @@ MsgMultiLineEdit::MsgMultiLineEdit(QWidget* parent,const char* name)
                 _diffDelColor(Qt::darkRed),
 		_currentUnicodeNumber(0)
 {
+   _whitespace = new QPixmap(2,2,-1,QPixmap::BestOptim);
+   _whitespace->fill(_textColor);
+   _errorWhitespace = new QPixmap(2,2,-1,QPixmap::BestOptim);
+   _errorWhitespace->fill(_errorColor);
+
+   _whitespaceNB = new QPixmap(3,3,-1,QPixmap::BestOptim);
+   _whitespaceNB->fill();
+   _errorWhitespaceNB = new QPixmap(3,3,-1,QPixmap::BestOptim);
+   _errorWhitespaceNB->fill();
+
+   QPainter p(_whitespaceNB);
+   p.setPen( _textColor );
+   p.drawEllipse(_whitespaceNB->rect());
+
+   QPainter q(_errorWhitespaceNB);
+   q.setPen( _errorColor );
+   q.drawEllipse(_errorWhitespaceNB->rect());
+					  
    diffPos.setAutoDelete(true);
    diffPos.clear();
    connect( this, SIGNAL( selectionChanged() ), this, SLOT( paintSpacePoints() ) );   
@@ -778,6 +799,10 @@ void MsgMultiLineEdit::setFont(const QFont& font)
 {
    QTextEdit::setFont(font);
 
+   QFontMetrics fm(font);
+   _wsOffsetX = QMAX(fm.width(' ')/2-2,1);
+   _wsOffsetY = QMAX(fm.height()/2-1,0);
+
    repaint();
 }
 
@@ -867,15 +892,31 @@ void MsgMultiLineEdit::paintSpacePoints()
 	int myrow = row;
 	int myrowY = rowY;
 	
+        QPixmap* ws, *wsnb;
+	
+	if( _currentColor== _errorColor )
+	{
+	    ws = _errorWhitespace;
+	    wsnb = _errorWhitespaceNB;
+	}
+	else
+	{
+	    ws = _whitespace;
+	    wsnb = _whitespaceNB;
+	}
+													
         while( mypar )
 	{
 	    QString s = text(myrow);
 	    int i = s.find( " " );
-	    while( (i >= 0) && (i < s.length()-1) ) // -1 because text will end by EOLN
+	    while( (i >= 0) && (i < (int)s.length()-1) ) // -1 because text will end by EOLN
 	    {
 		QTextStringChar* ch=mypar->at(i);
 		p = contentsToViewport( QPoint(ch->x,myrowY));
-		painter.drawEllipse( p.x()+mypar->string()->width(i)/2-1, p.y()+mypar->lineHeight(0)/2,2,2 );
+		if( ch->c.unicode() == 0x00A0U )
+		    bitBlt(viewport(), QPoint(p.x()+_wsOffsetX, p.y()+_wsOffsetY), wsnb, wsnb->rect(), Qt::CopyROP);
+		else
+		    bitBlt(viewport(), QPoint(p.x()+_wsOffsetX, p.y()+_wsOffsetY), ws, wsnb->rect(), Qt::CopyROP);
 		i = s.find( " ", i+1 );
     	    }
 	    myrowY+=mypar->lineHeight(0);
@@ -907,7 +948,7 @@ void MsgMultiLineEdit::paintSpacePoints()
     
     if( _showDiff && (!_diffUnderlineAdd || !_diffStrikeOutDel) )
     {
-	if( paragraphs() == diffPos.size() ) // sanity check
+	if( paragraphs() == (int)diffPos.size() ) // sanity check
 	{
 	painter.setRasterOp( Qt::AndROP );
 	for( int myrow = row; myrow < paragraphs() ; myrow++ ) {
@@ -943,7 +984,7 @@ void MsgMultiLineEdit::paintSpacePoints()
 
     if( _showDiff && (_diffUnderlineAdd || _diffStrikeOutDel) )
     {
-	if( paragraphs() == diffPos.size() ) // sanity check
+	if( paragraphs() == (int)diffPos.size() ) // sanity check
 	{
 	for( int myrow = row ; myrow < paragraphs() ; myrow++ ) {
 	    r = paragraphRect(myrow);
@@ -1023,12 +1064,12 @@ void MsgMultiLineEdit::highlight()
 
 	// setup new colors
 	
-	int i;
+	uint i;
 	
 	QRegExp markup("(\\\\)|(\")|(\\\\[abfnrtv'\"\?\\\\])|(\\\\\\d+)|(\\\\x[\\dabcdef]+)"
 	    "|(%[\\ddioxXucsfeEgGphln]+)|(&[^\\s])|(&[\\w-]+;)");
 
-	for( i = QMAX(_firstChangedLine,0) ; i < QMIN(_lastChangedLine+1,paragraphs()) ; i++ ) {
+	for( i = QMAX(_firstChangedLine,0) ; i < QMIN(_lastChangedLine+1,(uint)paragraphs()) ; i++ ) {
 	
 	QString line=text(i);
 
@@ -1072,7 +1113,7 @@ void MsgMultiLineEdit::highlight()
 	int tagindex=0;
 	int taglength=0;
 	int lineindex=0;
-	int index=0;
+	uint index=0;
 	int startPara, endPara, startIndex, endIndex;
 	QString t= text();
 	
@@ -1109,7 +1150,7 @@ void MsgMultiLineEdit::highlight()
 	    taglength=re.matchedLength();
 	}
 	
-	while( tagindex >= 0 && index<paragraphs())
+	while( tagindex >= 0 && (int)index<paragraphs())
 	{
 	    while( tagindex>=lineindex  && index<_lastChangedLine+2) 
 		lineindex+=paragraphLength(index++)+1;
@@ -1123,7 +1164,7 @@ void MsgMultiLineEdit::highlight()
 	    
 	    tagindex+=taglength;
 
-	    while( tagindex>=lineindex && index<paragraphs()) 
+	    while( tagindex>=lineindex && (int)index<paragraphs()) 
 		lineindex+=paragraphLength(index++)+1;
 	    lineindex-=paragraphLength(index-1);
 	    lineindex--;
