@@ -52,7 +52,7 @@ public:
    virtual void insertAt ( const QString & s, int line, int col, bool mark = false );
    virtual void removeLine ( int line );
 
-   int pos2Offset(int paragraph, int index);
+   int pos2Offset(uint paragraph, uint index);
    void offset2Pos(int offset, int &row, int &col) const;
    /** 
 	* @returns the current position in text, where the cursor is
@@ -222,6 +222,14 @@ private:
    QColor _errorColor;
    QColor _currentColor;
 
+   QPixmap* _whitespace;
+   QPixmap* _whitespaceNB;
+   QPixmap* _errorWhitespace;
+   QPixmap* _errorWhitespaceNB;
+
+   int _wsOffsetX;
+   int _wsOffsetY;
+
    bool _hlSyntax;
    QColor _quoteColor;
    QColor _unquoteColor;
