@@ -20,11 +20,12 @@
 
 **************************************************************************** */
 #include "dictionarymenu.h"
-#include <kaccel.h>
-#include <kdebug.h>
+#include <qaccel.h>
 #include <qpopupmenu.h>
+#include <kdebug.h>
+#include <kshortcut.h>
 
-DictionaryMenu::DictionaryMenu(QPopupMenu *popupMenu, KAccel *_accel
+DictionaryMenu::DictionaryMenu(QPopupMenu *popupMenu, QAccel *_accel
         , QObject *parent)
               : QObject(parent, "dictionarymenu")
               , popup(popupMenu)
@@ -53,7 +54,7 @@ void DictionaryMenu::clear()
    if(popup)
    {
       QIntDictIterator<QString> it( num2id ); // iterator for dict
-      while ( it.current() ) 
+      while ( it.current() )
       {
          popup->removeItem(it.currentKey());
          ++it;
@@ -61,11 +62,11 @@ void DictionaryMenu::clear()
    }
 
    num2id.clear();
-   
+
    if(accel)
    {
       QIntDictIterator<QString> it( accel2id ); // iterator for dict
-      while ( it.current() ) 
+      while ( it.current() )
       {
          accel->QAccel::removeItem(it.currentKey());
          ++it;
@@ -100,16 +101,16 @@ void DictionaryMenu::add(const QString& n, const QString& moduleId
             {
                 keyString=key.arg(accel2id.count()+1);
             }
-            int k = KAccel::stringToKey(keyString);
+            KShortcut k(keyString);
 
-            if(k!=0)
+            if(!k.isNull())
             {
                 int id=accel->QAccel::insertItem(k);
                 QString *idString = new QString(moduleId);
                 accel2id.insert(id,idString);
 
                 name+='\t';
-                name+=KAccel::keyToString(k,true);
+                name+=k.toString();
             }
             else
             {
