@@ -23,6 +23,7 @@
 #include <qinputdialog.h>
 #include <klocale.h>
 #include <kdebug.h>
+#include <kio/netaccess.h>
 #include <kmessagebox.h>
 #include <kfiledialog.h>
 #include <kurlrequester.h>
@@ -137,6 +138,58 @@ bool KDBSearchEngine::loadDatabase(QString database,bool noask=false)
  
   if(ret)
   {
+      // test, if there are both of ,old and standard databases
+      QString transFile = database+"/translations."+lang+".db";
+      
+      bool oldstuff = QFile::exists( transFile+",old" );
+      bool newstuff = QFile::exists( transFile );
+      
+      if( oldstuff && newstuff ) {
+        // there is an old db2 database, ask user
+	
+	if( KMessageBox::questionYesNo(0
+	    ,i18n("<p>There are backup database files from previous versions "
+	    "of KBabel. However, another version of KBabel (probably from KDE 3.1.1 or 3.1.2) "
+	    "created a new database. As a result, your KBabel installation contains two versions "
+	    "of database files. Unfortunatelly, the old and new version "
+	    "can't be merged. You need to choose one of them.<br/><br/>"
+	    "If you choose the old version, the new one will be removed. "
+	    "If you choose the new version, the old database files will be left alone "
+	    "and you need to remove them manually. Otherwise this message will be displayed "
+	    "again (the old files are at $KDEHOME/share/apps/kbabeldict/dbsearchengine/*,old).</p>")
+	    , i18n("Old database found"), i18n("Use &old database"), i18n("Use &new database")
+	  ) == KMessageBox::Yes ) {
+	    // remove the new files
+	    QFile::remove( transFile );
+	    QFile::remove( database+"/wordsindex."+lang+".db" );
+	    QFile::remove( database+"/keysindex."+lang+".db" );
+	    QFile::remove( database+"/catalogsinfo."+lang+".db" );
+	    
+	    // rename the old files
+	    KIO::NetAccess::copy( transFile+",old", transFile );
+	    KIO::NetAccess::copy( database+"/wordsindex."+lang+".db,old", database+"/wordsindex."+lang+".db" );
+	    KIO::NetAccess::copy( database+"/keysindex."+lang+".db,old", database+"/keysindex."+lang+".db" );
+	    KIO::NetAccess::copy( database+"/catalogsinfo."+lang+".db,old", database+"/catalogsinfo."+lang+".db" );
+
+	    QFile::remove( transFile+",old" );
+	    QFile::remove( database+"/wordsindex."+lang+".db,old" );
+	    QFile::remove( database+"/keysindex."+lang+".db,old" );
+	    QFile::remove( database+"/catalogsinfo."+lang+".db,old" );
+	  }
+      }
+      else if ( oldstuff ) {
+    	  // rename the old files
+	    KIO::NetAccess::copy( transFile+",old", transFile );
+	    KIO::NetAccess::copy( database+"/wordsindex."+lang+".db,old", database+"/wordsindex."+lang+".db" );
+	    KIO::NetAccess::copy( database+"/keysindex."+lang+".db,old", database+"/keysindex."+lang+".db" );
+	    KIO::NetAccess::copy( database+"/catalogsinfo."+lang+".db,old", database+"/catalogsinfo."+lang+".db" );
+
+	    QFile::remove( transFile+",old" );
+	    QFile::remove( database+"/wordsindex."+lang+".db,old" );
+	    QFile::remove( database+"/keysindex."+lang+".db,old" );
+	    QFile::remove( database+"/catalogsinfo."+lang+".db,old" );
+      }
+      
       dm= new DataBaseManager(database,lang,this,"Database manager");
 
       if(!dm->isOk())
@@ -539,9 +592,10 @@ bool KDBSearchEngine::startSearchNow(int searchmode)
     {
       idMod=&((*it).string);
 	int pos;
-	for(i=0;i<len;i++)
+	for(i=0;i<len;i++){
 	 while((pos=idMod->find(remchar.at(i)))!=-1)
 	idMod->remove(pos,1);
+	}
 
         if(comm)
 	 idMod->replace(QRegExp("\\_\\:.*\\\\n"),"");  //Read it from catalog !!! (NOT ONLY HERE)
@@ -571,8 +625,9 @@ bool KDBSearchEngine::startSearchNow(int searchmode)
   bool gk=(searchmode==MD_GOOD_KEYS)||allkey;
   int k=0;
   
-  if(gk) {
+    if(gk) {
      goodkeys=searchWords(mainRequest,thre,threorig,listmax);//FIX IT, mainReq?
+     if( goodkeys.count() == 0 ) gk = false; // if no good keys, use the whole database
 	}
    totalprogress=gk?goodkeys.count():totalRecord;
    int step=(totalprogress/30)+1;
@@ -585,7 +640,7 @@ bool KDBSearchEngine::startSearchNow(int searchmode)
 
 //   Emit progress, process event and check stop now
       if(count%step==0){
-           emit progress(100*count/QMAX(totalprogress,1));
+           emit progress(100*count/ /*QMAX(*/totalprogress/*,1)*/);
            kapp->processEvents(100);
          }
       if(stopNow) {
@@ -963,7 +1018,6 @@ PrefWidget * KDBSearchEngine::preferencesWidget(QWidget *parent)
 {
 
  pw =  new PreferencesWidget(parent);
- kdDebug(0) << "new pref" << endl;
  setSettings();
  connect(pw,SIGNAL(restoreNow()),this,SLOT(setSettings()));
  connect(pw,SIGNAL(applyNow()),this,SLOT(updateSettings()));
