@@ -10,20 +10,21 @@ class KSimpleConfig;
 class BugCache
 {
     public:
-        BugCache();
+        BugCache( const QString &id );
         ~BugCache();
 
         void savePackageList( const Package::List &pkgs );
         Package::List loadPackageList();
         void invalidatePackageList();
 
-        void saveBugList( const Package &pkg, const Bug::List & );
-        Bug::List loadBugList( const Package &pkg, bool disconnected );
-        void invalidateBugList( const Package &pkg );
+        void saveBugList( const Package &pkg, const QString &component, const Bug::List & );
+        Bug::List loadBugList( const Package &pkg, const QString &component, bool disconnected );
+        void invalidateBugList( const Package &pkg, const QString &component );
 
         void saveBugDetails( const Bug &bug, const BugDetails & );
         BugDetails loadBugDetails( const Bug &bug );
         void invalidateBugDetails( const Bug &bug );
+        bool hasBugDetails( const Bug& bug ) const;
 
     private:
         void writePerson( KSimpleConfig *file, const QString &key,
