@@ -1,16 +1,18 @@
 #ifndef __bugdetailsjob_h__
 #define __bugdetailsjob_h__
 
-#include "htmlbugjob.h"
+#include "xmlbugjob.h"
 #include "bug.h"
 #include "bugdetails.h"
 #include "bugdetailspart.h"
 
-class BugDetailsJob : public HTMLBugJob
+#include <qdom.h>
+
+class BugDetailsJob : public XmlBugJob
 {
     Q_OBJECT
 public:
-    BugDetailsJob();
+    BugDetailsJob( BugServer * );
     virtual ~BugDetailsJob();
 
     void start( const Bug &bug );
@@ -19,19 +21,12 @@ signals:
     void bugDetailsAvailable( const Bug &bug, const BugDetails &details );
 
 protected:
-    virtual void process();
-    virtual void processNode( const DOM::Node &n );
+    virtual void process( const QByteArray &data );
+
+    BugDetails parseDomElement( const QDomElement &element );
 
 private:
-    QString parseAttribute( QString &text, const QString &attr );
-
     Bug m_bug;
-    BugDetails m_bugDetails;
-
-    BugDetailsPart::List m_parts;
-    
-    QString mSender;
-    QString mDate;
 };
 
 #endif
