@@ -21,8 +21,10 @@ public:
     ~Package();
 
     QString name() const;
+    QString description() const;
     uint numberOfBugs() const;
     Person maintainer() const;
+    const QStringList& components() const;
 
     bool isNull() const { return m_impl == 0; }
 
