@@ -2,7 +2,7 @@
     buglvi.cpp  -  Custom QListViewItem that holds a Bug object
 
     copyright   : (c) 2001 by Martijn Klingens
-    email       : mklingens@yahoo.com
+    email       : klingens@kde.org
 
     *************************************************************************
     *                                                                       *
@@ -21,6 +21,7 @@
 #include <kdebug.h>
 
 #include "bugsystem.h"
+#include "bugserver.h"
 
 #include "buglvi.h"
 
@@ -29,14 +30,20 @@ using namespace KBugBusterMainWindow;
 BugLVI::BugLVI( QListView *parent , const Bug &bug )
 : QListViewItem( parent, bug.number() + "  ",
                  bug.title(), //KStringHandler::csqueeze( bug.title(), 70 ),
-                 Bug::statusToString( bug.status() ),
-                 Bug::severityToString( bug.severity() ),
+                 Bug::statusLabel( bug.status() ),
+                 Bug::severityLabel( bug.severity() ),
                  bug.submitter().fullName() )
 {
     m_bug = bug;
 
-    bool hasCommands = BugSystem::self()->hasCommandsFor( bug );
+    bool hasCommands = BugSystem::self()->server()->hasCommandsFor( bug );
     mCommandState = hasCommands ? BugCommand::Queued : BugCommand::None;
+
+    Person developer = bug.developerTODO();
+    if (!developer.name.isNull() && !developer.name.isEmpty())
+    {
+      setText(2, Bug::statusLabel(bug.status()) + " (" + developer.name + ")");
+    }
 }
 
 BugLVI::~BugLVI()
