@@ -6,7 +6,7 @@
 #include "bug.h"
 #include "package.h"
 
-class QTextEdit;
+class KTextEdit;
 class QSplitter;
 class KListBox;
 
@@ -40,10 +40,11 @@ class MsgInputDialog : public KDialogBase
     void readConfig();
     void writeConfig();
   
-    QTextEdit *mMessageEdit;
+    QComboBox *mRecipient;
+    KTextEdit *mMessageEdit;
     QSplitter *mSplitter;
     KListBox *mPresets;
-    
+
     Bug mBug;
     Package mPackage;
     MessageType mType;
