@@ -1,6 +1,6 @@
 #ifndef KBBPREFS_H
 #define KBBPREFS_H
-// $Id: kbbprefs.h,v 1.8 2002/03/02 10:28:24 binner Exp $
+// $Id: kbbprefs.h,v 1.10 2002/09/26 09:16:54 cschumac Exp $
 // (C) 2001 by Cornelius Schumacher
 
 #include <qmap.h>
@@ -43,6 +43,7 @@ class KBBPrefs : public KPrefs
     bool            mShowClosedBugs;
     bool            mShowWishes;
     bool            mSendBCC;
+    QString         mBugzillaURL;
     QString         mOverrideRecipient;
 
     QMap<QString,QString> mMessageButtons;
@@ -50,6 +51,8 @@ class KBBPrefs : public KPrefs
     int mMsgDlgWidth;
     int mMsgDlgHeight;
     QValueList<int> mMsgDlgSplitter;
+
+    QStringList mServers;
 };
 
 #endif
