@@ -25,6 +25,7 @@
 #include <kstdaction.h>
 #include <kmessagebox.h>
 #include <kfiledialog.h>
+#include <ksqueezedtextlabel.h>
 #include <kuserprofile.h>
 #include <kdebug.h>
 
@@ -175,10 +176,10 @@ void KompareShell::compare(const KURL& source,const KURL& destination )
 
 void KompareShell::setupActions()
 {
-	new KAction( i18n("&Compare Files..."), "fileopen", Qt::CTRL + Qt::Key_O,
+	KStdAction::open(this, SLOT(slotFileOpen()), actionCollection());
+	new KAction( i18n("&Compare Files..."), "fileopen", Qt::CTRL + Qt::Key_C,
 	              this, SLOT(slotFileCompareFiles()),
 	              actionCollection(), "file_compare_files" );
-	KStdAction::open(this, SLOT(slotFileOpen()), actionCollection());
 	KStdAction::quit(kapp, SLOT(quit()), actionCollection());
 
 	m_toolbarAction = KStdAction::showToolbar(this, SLOT(optionsShowToolbar()), actionCollection());
@@ -195,8 +196,9 @@ void KompareShell::setupStatusBar()
 	// Made these entries permanent so they will appear on the right side
 	statusBar()->insertItem( i18n(" 0 of 0 differences "), ID_N_OF_N_DIFFERENCES, 0, true );
 	statusBar()->insertItem( i18n(" 0 of 0 files "), ID_N_OF_N_FILES, 0, true );
-	statusBar()->insertItem( "", ID_GENERAL, 1 );
-	statusBar()->setItemAlignment( ID_GENERAL, AlignLeft );
+	m_generalLabel = new KSqueezedTextLabel( "", 0, "general_statusbar_label" );
+	statusBar()->addWidget( m_generalLabel, 1, false );
+	m_generalLabel->setAlignment( Qt::AlignLeft );
 }
 
 void KompareShell::updateStatusBar()
@@ -226,7 +228,7 @@ void KompareShell::updateStatusBar()
 
 void KompareShell::slotSetStatusBarText( const QString& text )
 {
-	statusBar()->changeItem( text, ID_GENERAL );
+	m_generalLabel->setText( text );
 }
 
 void KompareShell::setCaption( const QString& caption )
@@ -239,15 +241,21 @@ void KompareShell::saveProperties(KConfig* config)
 	// The 'config' object points to the session managed
 	// config file.  Anything you write here will be available
 	// later when this app is restored
-	if ( m_mode == Kompare::Compare )
+	if ( m_mode == Kompare::ComparingFiles )
 	{
-		config->writeEntry( "Mode", "Compare" );
+		config->writeEntry( "Mode", "ComparingFiles" );
 		config->writeEntry( "SourceUrl", m_sourceURL.url() );
 		config->writeEntry( "DestinationUrl", m_destinationURL.url() );
 	}
-	else if ( m_mode == Kompare::Diff )
+	else if ( m_mode == Kompare::ComparingDirs )
 	{
-		config->writeEntry( "Mode", "Diff" );
+		config->writeEntry( "Mode", "ComparingDirs" );
+		config->writeEntry( "SourceUrl", m_sourceURL.url() );
+		config->writeEntry( "DestinationUrl", m_destinationURL.url() );
+	}
+	else if ( m_mode == Kompare::ShowingDiff )
+	{
+		config->writeEntry( "Mode", "ShowingDiff" );
 		config->writeEntry( "DiffUrl", m_diffURL.url() );
 	}
 
@@ -261,10 +269,10 @@ void KompareShell::readProperties(KConfig* config)
 	// the app is being restored. Read in here whatever you wrote
 	// in 'saveProperties'
 
-	QString mode = config->readEntry( "Mode", "Compare" );
-	if ( mode == "Compare" )
+	QString mode = config->readEntry( "Mode", "ComparingFiles" );
+	if ( mode == "ComparingFiles" )
 	{
-		m_mode  = Kompare::Compare;
+		m_mode  = Kompare::ComparingFiles;
 		m_sourceURL  = config->readEntry( "SourceUrl", "" );
 		m_destinationURL = config->readEntry( "DestinationFile", "" );
 
@@ -272,9 +280,19 @@ void KompareShell::readProperties(KConfig* config)
 
 		m_viewPart->compare( m_sourceURL, m_destinationURL );
 	}
-	else if ( mode == "Diff" )
+	else if ( mode == "ComparingDirs" )
 	{
-		m_mode = Kompare::Diff;
+		m_mode  = Kompare::ComparingDirs;
+		m_sourceURL  = config->readEntry( "SourceUrl", "" );
+		m_destinationURL = config->readEntry( "DestinationFile", "" );
+
+		m_viewPart->loadSettings( config );
+
+		m_viewPart->compare( m_sourceURL, m_destinationURL );
+	}
+	else if ( mode == "ShowingDiff" )
+	{
+		m_mode = Kompare::ShowingDiff;
 		m_diffURL = config->readEntry( "DiffUrl", "" );
 
 		m_viewPart->loadSettings( config );
