@@ -14,6 +14,18 @@ using namespace std;
 
 QString translate(QString xml, QString orig, QString translation)
 {
+    QString prefix;
+    while (xml.at(0) == '<' && orig.at(0) != '<') {
+        // a XML tag as prefix
+        int index = xml.find('>');
+        assert(index != -1);
+        index++;
+        while (xml.at(index) == ' ')
+            index++;
+        prefix = prefix + xml.left(index);
+        xml = xml.mid(index, xml.length());
+    }
+
     int index = xml.find(orig);
     if (index == -1) {
         qWarning("can't find\n%s\nin\n%s", orig.latin1(), xml.latin1());
@@ -25,7 +37,33 @@ QString translate(QString xml, QString orig, QString translation)
                     QString::fromLatin1(""));
     } else
         xml.replace(index, orig.length(), translation);
-    return xml;
+    return prefix + xml;
+}
+
+static char * shell_quote(const char *s)
+{
+   char *result;
+   char *p;
+   p = result = (char *) malloc(strlen(s)*5+3);
+   *p++ = '\'';
+   while(*s)
+   {
+     if (*s == '\'')
+     {
+        *p++ = '\'';
+        *p++ = '"';
+        *p++ = *s++;
+        *p++ = '"';
+        *p++ = '\'';
+     }
+     else
+     {
+        *p++ = *s++;
+     }
+   }
+   *p++ = '\'';
+   *p = '\0';
+   return result;
 }
 
 
@@ -68,7 +106,11 @@ int main( int argc, char **argv )
     QString output;
     QTextStream ts(&output, IO_WriteOnly);
     if (xml_text.left(5) != "<?xml") {
-        FILE *p = popen(QString::fromLatin1("xmlizer %1").arg(argv[1]).latin1(), "r");
+        char *quoted_file = shell_quote(argv[1]);
+        QCString cmd = "xmlizer ";
+        cmd += quoted_file;
+        FILE *p = popen(cmd, "r");
+        free(quoted_file);
         xml.open(IO_ReadOnly, p);
         char buffer[5001];
         xml_text.truncate(0);
